/*
 * Copyright 2014 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.common.protocol;


/**
 * Base class for <code>CA_PROTO_CREATE_CHAN</code> messages.
 * 
 * @author Sebastian Marsching
 * @see ChannelAccessCommand#CA_PROTO_CREATE_CHAN
 */
public abstract class ChannelAccessConnectChannelMessage extends
        ChannelAccessMessage {

    /**
     * Constructor. This constructor only sets the message command to
     * {@link ChannelAccessCommand#CA_PROTO_CREATE_CHAN}. All other fields
     * depend on the context in which the message is sent. This constructor is
     * package-private, so that only classes in this package can inherit from
     * this class.
     */
    ChannelAccessConnectChannelMessage() {
        super(ChannelAccessCommand.CA_PROTO_CREATE_CHAN);
    }

    /**
     * Constructor. This constructor sets the message command to
     * {@link ChannelAccessCommand#CA_PROTO_CREATE_CHAN} and stores the message
     * header that is used to construct this message. All other fields depend on
     * the context in which the message is sent. This constructor is
     * package-private, so that only classes in this package can inherit from
     * this class.
     * 
     * @param messageHeader
     *            the message header that is used to for creating this message.
     *            This header is passed on to the
     *            {@link ChannelAccessMessage#ChannelAccessMessage(ChannelAccessCommand, ChannelAccessMessageHeader)}
     *            constructor.
     */
    ChannelAccessConnectChannelMessage(ChannelAccessMessageHeader messageHeader) {
        super(ChannelAccessCommand.CA_PROTO_CREATE_CHAN, messageHeader);
    }

}
